@@ -22,14 +22,11 @@
 
 // Qt
 #include <QHBoxLayout>
-#include <QLabel>
 #include <QKeyEvent>
 #include <QTimer>
 #include <QToolButton>
 #include <QMenu>
 #include <QApplication>
-#include <QPaintEvent>
-#include <QPainter>
 
 // KDE
 #include <KColorScheme>
@@ -54,12 +51,8 @@ IncrementalSearchBar::IncrementalSearchBar(QWidget *parent) :
     setPalette(qApp->palette());
     setAutoFillBackground(true);
 
-    auto closeButton = new QToolButton(this);
-    closeButton->setObjectName(QStringLiteral("close-button"));
-    closeButton->setToolTip(i18nc("@info:tooltip", "Close the search bar"));
-    closeButton->setAutoRaise(true);
-    closeButton->setIcon(QIcon::fromTheme(QStringLiteral("dialog-close")));
-    connect(closeButton, &QToolButton::clicked, this, &Konsole::IncrementalSearchBar::closeClicked);
+    // SubWindow flag limits tab focus switching to this widget
+    setWindowFlags(windowFlags() | Qt::SubWindow);
 
     _searchEdit = new QLineEdit(this);
     _searchEdit->setClearButtonEnabled(true);
@@ -70,6 +63,8 @@ IncrementalSearchBar::IncrementalSearchBar(QWidget *parent) :
     _searchEdit->setCursor(Qt::IBeamCursor);
     _searchEdit->setStyleSheet(QString());
     _searchEdit->setFont(QApplication::font());
+    // When the widget focus is set, focus input box instead
+    setFocusProxy(_searchEdit);
 
     setCursor(Qt::ArrowCursor);
     // text box may be a minimum of 6 characters wide and a maximum of 10 characters wide
@@ -95,6 +90,7 @@ IncrementalSearchBar::IncrementalSearchBar(QWidget *parent) :
     _findNextButton->setAutoRaise(true);
     _findNextButton->setToolTip(i18nc("@info:tooltip",
                                       "Find the next match for the current search phrase"));
+    _findNextButton->installEventFilter(this);
     connect(_findNextButton, &QToolButton::clicked, this,
             &Konsole::IncrementalSearchBar::findNextClicked);
 
@@ -105,13 +101,14 @@ IncrementalSearchBar::IncrementalSearchBar(QWidget *parent) :
     _findPreviousButton->setToolButtonStyle(Qt::ToolButtonIconOnly);
     _findPreviousButton->setToolTip(i18nc("@info:tooltip",
                                           "Find the previous match for the current search phrase"));
+    _findPreviousButton->installEventFilter(this);
     connect(_findPreviousButton, &QToolButton::clicked, this,
             &Konsole::IncrementalSearchBar::findPreviousClicked);
 
     _searchFromButton = new QToolButton(this);
     _searchFromButton->setAutoRaise(true);
-
     _searchFromButton->setObjectName(QStringLiteral("search-from-button"));
+    _searchFromButton->installEventFilter(this);
     connect(_searchFromButton, &QToolButton::clicked, this,
             &Konsole::IncrementalSearchBar::searchFromClicked);
 
@@ -123,6 +120,15 @@ IncrementalSearchBar::IncrementalSearchBar(QWidget *parent) :
     optionsButton->setToolTip(i18nc("@info:tooltip", "Display the options menu"));
     optionsButton->setIcon(QIcon::fromTheme(QStringLiteral("configure")));
     optionsButton->setAutoRaise(true);
+    optionsButton->installEventFilter(this);
+
+    auto closeButton = new QToolButton(this);
+    closeButton->setObjectName(QStringLiteral("close-button"));
+    closeButton->setToolTip(i18nc("@info:tooltip", "Close the search bar"));
+    closeButton->setAutoRaise(true);
+    closeButton->setIcon(QIcon::fromTheme(QStringLiteral("dialog-close")));
+    closeButton->installEventFilter(this);
+    connect(closeButton, &QToolButton::clicked, this, &Konsole::IncrementalSearchBar::closeClicked);
 
     // Fill the options menu
     auto optionsMenu = new QMenu(this);
@@ -207,43 +213,40 @@ void IncrementalSearchBar::setSearchText(const QString &text)
 
 bool IncrementalSearchBar::eventFilter(QObject *watched, QEvent *event)
 {
-    if ((event->type() != QEvent::KeyPress) || watched != _searchEdit) {
-        return QWidget::eventFilter(watched, event);
-    }
+    if (event->type() == QEvent::KeyPress || event->type() == QEvent::KeyRelease) {
+        auto *keyEvent = static_cast<QKeyEvent *>(event);
+        QToolButton *toolButton = nullptr;
 
-    auto *keyEvent = static_cast<QKeyEvent *>(event);
-    if (keyEvent->key() == Qt::Key_Escape) {
-        emit closeClicked();
-        return true;
+        if (keyEvent->key() == Qt::Key_Return) {
+            if (watched == _searchEdit && event->type() == QEvent::KeyPress) {
+                if (keyEvent->modifiers() == Qt::NoModifier) {
+                    _findNextButton->click();
+                    return true;
+                }
+                if (keyEvent->modifiers() == Qt::ShiftModifier) {
+                    _findPreviousButton->click();
+                    return true;
+                }
+                if (keyEvent->modifiers() == Qt::ControlModifier) {
+                    _searchFromButton->click();
+                    return true;
+                }
+            } else if ((toolButton = qobject_cast<QToolButton *>(watched)) != nullptr) {
+                if(event->type() == QEvent::KeyPress && !toolButton->isDown()) {
+                    toolButton->setDown(true);
+                    toolButton->pressed();
+                } else if (toolButton->isDown()) {
+                    toolButton->setDown(keyEvent->isAutoRepeat());
+                    toolButton->released();
+                    toolButton->click();
+                }
+                return true;
+            }
+        }
     }
-
-    if (keyEvent->key() == Qt::Key_Return && !keyEvent->modifiers()) {
-        _findNextButton->click();
-        return true;
-    }
-
-    if ((keyEvent->key() == Qt::Key_Return)
-        && (keyEvent->modifiers() == Qt::ShiftModifier)) {
-        _findPreviousButton->click();
-        return true;
-    }
-
-    if ((keyEvent->key() == Qt::Key_Return)
-        && (keyEvent->modifiers() == Qt::ControlModifier)) {
-        _searchFromButton->click();
-        return true;
-    }
-
     return QWidget::eventFilter(watched, event);
 }
 
-void IncrementalSearchBar::correctPosition(const QSize &parentSize)
-{
-    const auto x = parentSize.width() - width();
-    const auto y = parentSize.height();
-    setGeometry(x, 0 + y, width(), height());
-}
-
 void IncrementalSearchBar::keyPressEvent(QKeyEvent *event)
 {
     static auto movementKeysToPassAlong = QSet<int>{
@@ -254,6 +257,10 @@ void IncrementalSearchBar::keyPressEvent(QKeyEvent *event)
         && (event->modifiers() == Qt::ShiftModifier)) {
         emit unhandledMovementKeyPressed(event);
     }
+
+    if (event->key() == Qt::Key_Escape) {
+        emit closeClicked();
+    }
 }
 
 void IncrementalSearchBar::setVisible(bool visible)
