@@ -186,6 +186,11 @@ public:
          * Only applicable if the UseCustomCursorColor property is true.
          */
         CustomCursorColor,
+        /** (QColor) The color used by terminal displays to draw the character
+         * underneath the cursor. Only applicable if the UseCustomCursorColor
+         * property is true and CursorShape property is Enum::BlockCursor.
+         */
+        CustomCursorTextColor,
         /** (QString) A string consisting of the characters used to delimit
          * words when selecting text in the terminal display.
          */
@@ -284,7 +289,7 @@ public:
          * Tracking events but don't indicate they're interested in those
          * events; for example, when vim doesn't indicate it's interested
          * in Mouse Tracking events (i.e. when the mouse is in Normal
-         * (not Visual) mode): http://vimdoc.sourceforge.net/htmldoc/intro.html#Normal
+         * (not Visual) mode): https://vimhelp.org/intro.txt.html#vim-modes-intro
          * mouse wheel scroll events will send up/down key press events.
          *
          * Default value is true.
@@ -524,12 +529,18 @@ public:
         return property<bool>(Profile::UseCustomCursorColor);
     }
 
-    /** Convenience method for property<bool>(Profile::CustomCursorColor) */
+    /** Convenience method for property<QColor>(Profile::CustomCursorColor) */
     QColor customCursorColor() const
     {
         return property<QColor>(Profile::CustomCursorColor);
     }
 
+    /** Convenience method for property<QColor>(Profile::CustomCursorTextColor) */
+    QColor customCursorTextColor() const
+    {
+        return property<QColor>(Profile::CustomCursorTextColor);
+    }
+
     /** Convenience method for property<QString>(Profile::WordCharacters) */
     QString wordCharacters() const
     {
@@ -751,7 +762,7 @@ public:
     /** Sets the value of @p property in each of the group's profiles to
      * @p value.
      */
-    void setProperty(Property p, const QVariant &value) Q_DECL_OVERRIDE;
+    void setProperty(Property p, const QVariant &value) override;
 
 private:
     Q_DISABLE_COPY(ProfileGroup)
