@@ -63,7 +63,7 @@ public:
      * between all views on a session.
      */
     explicit ScreenWindow(Screen *screen, QObject *parent = nullptr);
-    ~ScreenWindow() Q_DECL_OVERRIDE;
+    ~ScreenWindow() override;
 
     /** Sets the screen which this window looks onto */
     void setScreen(Screen *screen);
