@@ -68,11 +68,11 @@ public:
      * subclasses, use object->deleteLater() to delete any widgets or other objects
      * instead of 'delete object'.
      */
-    ~TabbedViewContainer() Q_DECL_OVERRIDE;
+    ~TabbedViewContainer() override;
 
     /** Adds a new view to the container widget */
     void addView(TerminalDisplay *view);
-    void addSplitter(ViewSplitter *splitter, int index = -1);
+    void addSplitter(ViewSplitter *viewSplitter, int index = -1);
 
     /** splits the currently focused Splitter */
     void splitView(TerminalDisplay *view, Qt::Orientation orientation);
@@ -141,8 +141,8 @@ public:
      */
     ViewSplitter *viewSplitterAt(int index);
 
-    void connectTerminalDisplay(TerminalDisplay *view);
-    void disconnectTerminalDisplay(TerminalDisplay *view);
+    void connectTerminalDisplay(TerminalDisplay *display);
+    void disconnectTerminalDisplay(TerminalDisplay *display);
     void moveTabLeft();
     void moveTabRight();
 
@@ -201,7 +201,7 @@ protected:
     // close tabs and unregister
     void closeTerminalTab(int idx);
 
-    void keyReleaseEvent(QKeyEvent *event) Q_DECL_OVERRIDE;
+    void keyReleaseEvent(QKeyEvent *event) override;
 private Q_SLOTS:
     void viewDestroyed(QObject *view);
     void konsoleConfigChanged();
