@@ -72,7 +72,7 @@ public:
      * and added to the specified @p collection.
      */
     ViewManager(QObject *parent, KActionCollection *collection);
-    ~ViewManager() Q_DECL_OVERRIDE;
+    ~ViewManager() override;
 
     /**
      * Creates a new view to display the output from and deliver input to @p session.
