@@ -57,7 +57,7 @@ void TerminalInterfaceTest::initTestCase()
     auto buildPath = libraryPaths.last();
     QCoreApplication::removeLibraryPath(buildPath);
     // konsolepart.so is in ../autotests/
-    if (buildPath.endsWith(QLatin1String("/autotests"))) {
+    if (buildPath.endsWith(QStringLiteral("/autotests"))) {
         buildPath.chop(10);
     }
     QCoreApplication::addLibraryPath(buildPath);
@@ -120,7 +120,7 @@ void TerminalInterfaceTest::testTerminalInterface()
     // int terminalProcessId  = terminal->terminalProcessId();
 
     // Let's try using QSignalSpy
-    // http://techbase.kde.org/Development/Tutorials/Unittests
+    // https://community.kde.org/Guidelines_and_HOWTOs/UnitTests
     // QSignalSpy is really a QList of QLists, so we take the first
     // list, which corresponds to the arguments for the first signal
     // we caught.
