@@ -119,9 +119,9 @@ public:
     bool hasChanged() const {
         for(const QButtonGroup *group: qAsConst(_groups)) {
             int value = buttonToEnumValue(group->checkedButton());
-            const auto enumItem = groupToConfigItemEnum(group);
+            const auto *enumItem = groupToConfigItemEnum(group);
 
-            if(!enumItem->isEqual(value)) {
+            if(enumItem != nullptr && !enumItem->isEqual(value)) {
                 return true;
             }
         }
